@@ -78,43 +78,58 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
         eprintln!("response = {:?}", text);
     }
 
-    let response: Response = serde_json::from_str(&text).unwrap();
+    let maybe_response: Result<Response, _> = serde_json::from_str(&text);
 
-    match response {
-        Response::Found(found_response) => {
-            if args.json {
-                if found_response.packages.is_empty() {
-                    println!("{}", json!({"error": "No packages found"}));
+    match maybe_response {
+        Ok(response) => match response {
+            Response::Found(found_response) => {
+                if args.json {
+                    if found_response.packages.is_empty() {
+                        println!("{}", json!({"error": "No packages found"}));
+                    } else {
+                        println!("{}", json!(found_response));
+                    }
                 } else {
-                    println!("{}", json!(found_response));
-                }
-            } else {
-                if found_response.packages.is_empty() {
-                    eprintln!("{}", style("No packages found").bold().yellow());
-                } else {
-                    for package in found_response.packages {
-                        println!(
-                            "{} -> {}",
-                            style(package.name).green(),
-                            style(
-                                package
-                                    .summary
-                                    .unwrap_or("no description available".to_string())
-                            )
-                        );
-                        println!("{}", style(package.url).dim());
-                        println!("");
+                    let packager = found_response.packager.as_str();
+                    let p = match packager {
+                        "pip" => style(format!(" {} ", packager)).bold().white().on_blue(),
+                        "npm" => style(format!(" {} ", packager)).bold().white().on_red(),
+                        "cargo" => style(format!(" {} ", packager)).bold().black().on_green(),
+                        _ => style(format!(" {} ", packager)).bold().white(),
+                    };
+                    println!("{}", p);
+                    println!("");
+                    if found_response.packages.is_empty() {
+                        println!("{}", style("No packages found").bold().yellow());
+                    } else {
+                        for package in found_response.packages {
+                            println!(
+                                "{} -> {}",
+                                style(package.name).green(),
+                                style(
+                                    package
+                                        .summary
+                                        .unwrap_or("no description available".to_string())
+                                )
+                            );
+                            println!("{}", style(package.url).dim());
+                            println!("");
+                        }
                     }
                 }
             }
-        }
-        Response::Error(error_response) => {
-            if args.json {
-                println!("{}", json!({ "error": error_response.error }));
-            } else {
-                eprintln!("error = {}", style(error_response.error).bold().red());
-                eprintln!("response = {}", style(text).bold().red());
+            Response::Error(error_response) => {
+                if args.json {
+                    println!("{}", json!({ "error": error_response.error }));
+                } else {
+                    eprintln!("error = {}", style(error_response.error).bold().red());
+                    eprintln!("response = {}", style(text).bold().red());
+                }
             }
+        },
+        Err(err) => {
+            eprintln!("{}", style(format!("{:?}", err)).bold().red());
+            eprintln!("{}", style("Use --verbose for more details").bold().red());
         }
     }
 
